@@ -2,7 +2,6 @@ package Mojo::Redis::Cache;
 use Mojo::Base -base;
 
 use Mojo::JSON;
-use Protocol::Redis::Faster;
 use Scalar::Util 'blessed';
 use Storable    ();
 use Time::HiRes ();
@@ -10,9 +9,7 @@ use Time::HiRes ();
 use constant OFFLINE => $ENV{MOJO_REDIS_CACHE_OFFLINE};
 
 has connection => sub {
-  OFFLINE
-    ? shift->_offline_connection
-    : shift->redis->_dequeue->protocol(Protocol::Redis::Faster->new(api => 1))->encoding(undef);
+  OFFLINE ? shift->_offline_connection : shift->redis->_dequeue->encoding(undef);
 };
 has deserialize    => sub { \&Storable::thaw };
 has default_expire => 600;
@@ -108,7 +105,7 @@ sub write_p {
 'Mojo::Redis::Connection::Offline';
 HERE
   my $redis = shift->redis;
-  return $c->new(protocol => $redis->protocol_class->new(api => 1), url => $redis->url);
+  return $c->new(url => $redis->url);
 }
 
 sub _time { Time::HiRes::time() }
